@@ -7,7 +7,7 @@ use 5.010;
 use Exporter 'import';
 
 our @EXPORT_OK = qw(parse);
-our $VERSION   = '1.20';  # optional prefixes in spec strings
+our $VERSION   = '1.21';
 
 =encoding utf8
 
@@ -17,7 +17,7 @@ CLI::Cmdline - Minimal command-line parser with short/long options and aliases i
 
 =head1 VERSION
 
-1.20
+1.21
 
 =head1 SYNOPSIS
 
@@ -28,6 +28,7 @@ CLI::Cmdline - Minimal command-line parser with short/long options and aliases i
 
     # only define options which have no default value 0 or '';
     my %opt = (
+	v       => 1,          # switch, will be incremented on each occurrence
         include => [],         # multiple values allowed
         config  => '/etc/myapp.conf',
     );
@@ -116,49 +117,57 @@ If you want multiple occurrences but don't want to pre-set an array:
     #!/usr/bin/perl
     use strict;
     use warnings;
+
+    use Data::Dumper $Data::Dumper::Sortkeys = 1;
     use CLI::Cmdline qw(parse);
 
-    my $switches = '-v -q --help --dry-run -f';
-    my $options  = '--input --output --mode --tag';
+    my $switches = '-v|verbose -q|quiet --help --dry-run -force|f';
+    my $options  = '-input|i -output -mode -tag';
+    my %opt      = ( v => 1, mode => 'normal', tag => [] );   # tag = multiple tags allowed
 
-    my %opt = (
-        mode    => 'normal',
-        tag     => [],            # multiple tags allowed
-    );
+    CLI::Cmdline::parse(\%opt, $switches, $options) 
+        	or die "Try '$0 --help' for more information. ARGV = @ARGV\n";
 
-    parse(\%opt, $switches, $options)
-        or die <<'USAGE';
-    Usage: process.pl [options] --input=FILE [files...]
+    #  --- check if ARGV is filled or help is required
+    Usage()        if $#ARGV < 0 || $opt{help};
+    die "Error: --input is required. See $0 --help for usage.\n"   if ($opt{input} eq '');
 
+    my $verbose = $opt{v} - $opt{q};
+    print "Starting processing (verbose $verbose)...\n" if $verbose > 0;
+
+    print Dumper(\%opt);
+    print "ARG = [".join('] [',@ARGV)."]\n";
+    exit 0;
+
+    sub Usage {
+        print <<"USAGE";
+    Usage  : $0 [options] --input=FILE [files...]
     Options:
-      -v                        Increase verbosity (repeatable)
-      -q                        Suppress normal output
+      -v|verbose                Increase verbosity (repeatable)
+      -q|quiet                  Suppress normal output
       --dry-run                 Show what would be done
-      -f                        Force operation even if risky
+      -f|force                  Force operation even if risky
       --input=FILE              Input file (required)
       --output=FILE             Output file (optional)
-      --mode=MODE               Processing mode (normal|fast|safe)
+      --mode=MODE               Processing mode, default: $opt{mode}
       --tag=TAG                 Add a tag (multiple allowed)
       --help                    Show this help message
 
     Example:
-      process.pl --input=data.csv --output=result.json --tag=2026 --tag=final -vv
-USAGE
-    if ($opt{h}) {
-        print <<'HELP';
-Full documentation goes here...
-HELP
-        exit 0;
+      $0 --input=data.csv -vvv file1.txt
+      $0 --input=data.csv --tag=2026 --tag=final -vv file1.txt
+      $0 --input=data.csv -quiet  file1.txt
+      $0 -input=data.csv -dry-run file1.txt   # not a long tag with =
+      $0 -input data.csv -vf file1.txt
+      $0 -vfi data.csv file1.txt
+      $0 -vif data.csv file1.txt              # option not at the end
+      $0 file1.txt                            # missing input error
+      $0 --help
+
+    USAGE
+        exit 1;
     }
 
-    if (!defined $opt{input}) {
-        die "Error: --input is required. See --help for usage.\n";
-    }
-
-    my $verbosity = $opt{v} - $opt{q};
-    print "Starting processing (verbosity $verbosity)...\n" if $verbosity > 0;
-
-
 =head2 Using -- to pass filenames starting with dash
 
     my %opt;
